#ifndef VTX_H
#define VTX_H

#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include <audacious/plugin.h>

void vtx_file_info(const char *filename);

#endif
